@@ -1,18 +1,13 @@
 #!/usr/bin/env python
 # coding: utf-8
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GNU Affero General Public License v3.0 License.
-
 
 # Copyright (c) Mito.
 # Distributed under the terms of the Modified BSD License.
-from packaging.version import Version
 import pandas as pd
 import pytest
 import json
 
-from mitosheet.tests.decorators import pandas_post_1_only
-from mitosheet.tests.test_utils import create_mito_wrapper_with_data, create_mito_wrapper
+from mitosheet.tests.test_utils import create_mito_wrapper, create_mito_wrapper_dfs
 
 
 def get_value_helper(sheet_data, row_index, column_index):
@@ -23,11 +18,11 @@ def test_sheet_json_displays_floats_correctly():
         'value': [1.0, 2.0, None],
     })
 
-    mito = create_mito_wrapper(df)
+    mito = create_mito_wrapper_dfs(df)
     
-    sheet_data = json.loads(mito.sheet_data_json)[0]
-    assert get_value_helper(sheet_data, 0, 0) == 1.0
-    assert get_value_helper(sheet_data, 1, 0) == 2.0
+    sheet_data = json.loads(mito.mito_widget.sheet_data_json)[0]
+    assert get_value_helper(sheet_data, 0, 0) == '1.0'
+    assert get_value_helper(sheet_data, 1, 0) == '2.0'
     assert get_value_helper(sheet_data, 2, 0) == 'NaN'
 
 
@@ -39,19 +34,18 @@ def test_sheet_json_displays_dates_correctly():
 
     df['date_of_birth'] = pd.to_datetime(df['date_of_birth'])
 
-    mito = create_mito_wrapper(df)
+    mito = create_mito_wrapper_dfs(df)
     
-    sheet_data = json.loads(mito.mito_backend.get_shared_state_variables()['sheet_data_json'])[0]
+    sheet_data = json.loads(mito.mito_widget.sheet_data_json)[0]
     assert get_value_helper(sheet_data, 0, 1) == '2005-10-25 00:00:00'
     assert get_value_helper(sheet_data, 1, 1) == '2002-10-02 00:00:00'
     assert get_value_helper(sheet_data, 2, 1)== '2001-11-14 00:00:00'
 
-@pandas_post_1_only
 def test_sheet_displays_dates_with_non_standard_dtype():
-    mito = create_mito_wrapper_with_data(['2016-01-31T19:29:50.000+0000', '2016-01-31T19:29:50.000+0000'])
-    mito.change_column_dtype(0, ['A'], 'datetime')
+    mito = create_mito_wrapper(['2016-01-31T19:29:50.000+0000', '2016-01-31T19:29:50.000+0000'])
+    mito.change_column_dtype(0, 'A', 'datetime')
 
-    sheet_data = json.loads(mito.mito_backend.get_shared_state_variables()['sheet_data_json'])[0]
+    sheet_data = json.loads(mito.mito_widget.sheet_data_json)[0]
     assert get_value_helper(sheet_data, 0, 0) == '2016-01-31 19:29:50'
     assert get_value_helper(sheet_data, 1, 0) == '2016-01-31 19:29:50'
 
@@ -62,23 +56,14 @@ def test_sheet_json_holds_timed_deltas():
         'dob2': ['2004-10-23 10:15:15','2002-10-2','2001-07-14 14:15:00', '2005-07-14 14:15:00']
     })
 
-    # Check if we're on pandas 2.0, and if so, use the mixed format
-    # to parse the dates.
-    if Version(pd.__version__) < Version('2.0'):
-        format = None
-    else:
-        format = 'mixed'
+    df['dob'] = pd.to_datetime(df['dob'])
+    df['dob2'] = pd.to_datetime(df['dob2'])
 
-
-    # Parse date with format YYYY-MM-DD HH:MM:SS
-    df['dob'] = pd.to_datetime(df['dob'], format=format)
-    df['dob2'] = pd.to_datetime(df['dob2'], format=format)
-
-    mito = create_mito_wrapper(df)
+    mito = create_mito_wrapper_dfs(df)
 
     mito.set_formula('=dob - dob2', 0, 'time_deltas', True)
     
-    sheet_data = json.loads(mito.mito_backend.get_shared_state_variables()['sheet_data_json'])[0]
+    sheet_data = json.loads(mito.mito_widget.sheet_data_json)[0]
     assert get_value_helper(sheet_data, 0, 2) == '364 days 13:44:45'
     assert get_value_helper(sheet_data, 1, 2) == '-61 days +05:12:00'
     assert get_value_helper(sheet_data, 2, 2) == '122 days 09:45:00'
@@ -89,15 +74,15 @@ def test_sheet_json_holds_timed_deltas_non_standard_dtype():
     december = pd.Series(pd.date_range("20121201", periods=4))
     january = pd.Series(pd.date_range("20130101", periods=4))
     td = january - december
-    td.astype("timedelta64[s]")
+    td.astype("timedelta64[D]")
 
     df = pd.DataFrame({
         'delta': td,
     })
 
-    mito = create_mito_wrapper(df)
+    mito = create_mito_wrapper_dfs(df)
     
-    sheet_data = json.loads(mito.mito_backend.get_shared_state_variables()['sheet_data_json'])[0]
+    sheet_data = json.loads(mito.mito_widget.sheet_data_json)[0]
     assert get_value_helper(sheet_data, 0, 0) == '31 days 00:00:00'
     assert get_value_helper(sheet_data, 1, 0) == '31 days 00:00:00'
     assert get_value_helper(sheet_data, 2, 0) == '31 days 00:00:00'
